/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * Copyright (c) 2001  HASEGAWA Masafumi
 */

#include "ebi_gaiji.h"
#include "ebi_book.h"
#include "ebi_subbook.h"
#include "ebi_bitmapfont.h"
#include "ebi_page.h"
#include "ebi_device.h"
#include "ebi_fontset.h"
#include "ebi_error.h"

__EBI_BEGIN_NAMESPACE

const TC Gaiji::c_altChar = 0x2237;

Gaiji::Gaiji (Subbook* subbook, int code, FontType fontType)
{
  m_subbook = subbook;
  m_code = code;
  m_fontType = fontType;

  m_width = 0;
  m_height = 0;
  m_pnt = toPNT (0, 0);
}

Gaiji::~Gaiji ()
{
}

W Gaiji::getWidth () const
{
  return m_width;
}

W Gaiji::updateSize (Device* device)
{
  m_width = device->getFontSize ();
  if (m_fontType == FONT_HALF)
    {
      m_width /= 2;
    }
  return m_width;
}

void Gaiji::updateLayout (PNT* pnt, W max)
{
  if (max > 0 && pnt->x + m_width >= max)
    {
      pnt->x = 0;
      ++pnt->y;
    }

  m_pnt = *pnt;
  pnt->x += m_width;
}

void Gaiji::draw (Device* device, W low, W high)
{
  if (m_pnt.y < low || m_pnt.y > high)
    {
      return;
    }
  if (m_pnt.x == 0)
    {
      device->newLine ();
    }

  Fontset* fontset = m_subbook->getBook ()->getFontset ();
  BitmapFont *bitmapFont = fontset->getBitmapFont (m_subbook->getSubbook (), m_code, m_fontType);
  SIZE size = { m_width, device->getFontSize () };
  device->drawBitmapFont (bitmapFont, size);
}

bool Gaiji::isHit (const PNT& pnt) const
{
  if ((pnt.x >= m_pnt.x && pnt.x < m_pnt.x + m_width) && pnt.y == m_pnt.y)
    {
      return true;
    }
  return false;
}

void Gaiji::getString (String* str) const
{
  *str += c_altChar;
}

__EBI_END_NAMESPACE

