/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * Copyright (c) 2001  HASEGAWA Masafumi
 */

#include "ebi_keywordpanel.h"
#include "databox.h"

__EBI_BEGIN_NAMESPACE

KeywordPanel::KeywordPanel () : Panel (PNL_KEYWORD)
{
  m_keyword[0] = TK_NULL;
  m_search = Book::SEARCH_WORD;
}

KeywordPanel::~KeywordPanel ()
{
}

Book::SearchMethod KeywordPanel::getSearchMethod ()
{
  return m_search;
}

void KeywordPanel::setSearchMethod (Book::SearchMethod search)
{
  m_search = search;
}

void KeywordPanel::getKeyword (String * str)
{
  *str = m_keyword;
}

void KeywordPanel::setKeyword (const String & str)
{
  tc_strncpy (m_keyword, (TC*) str.c_str (), EB_MAX_WORD_LENGTH);
  m_keyword[EB_MAX_WORD_LENGTH] = TK_NULL;
}

bool KeywordPanel::onBeforeCreate ()
{
  TEXTBOX* textBox = (TEXTBOX*) ptrstdpnl (PNL_TB_KEYWORD);
  textBox->text = m_keyword;

  SWSEL* swSel = (SWSEL*) ptrstdpnl (PNL_WS_METHOD);
  swSel->cv = m_search + 1;

  return true;
}

W KeywordPanel::onMsSet (W ino, W value)
{
  W pid = pidstdpnl (PNL_TB_KEYWORD);
  ccut_txt (pid, 0, NULL, 0);
  cget_val (pid, EB_MAX_WORD_LENGTH + 1, (W*) m_keyword);
      
  pid = pidstdpnl (PNL_WS_METHOD);
  m_search = (Book::SearchMethod) (cget_val (pid, 0, NULL) - 1);
      
  if (m_keyword[0] == TK_NULL)
    {
      errpanel (ER_KEYWORD, 0);
      return -1;
    }
  return ino;
}

W KeywordPanel::onCommand (W ino, W value)
{
  switch (ino)
    {
    case PNL_MS_SET:
      return onMsSet (ino, value);

    case PNL_MS_EXIT:
      return ino;
	
    case PNL_TB_KEYWORD:
    case PNL_WS_METHOD:
      break;
    }

  return -1;
}

__EBI_END_NAMESPACE
