/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * Copyright (c) 2001  HASEGAWA Masafumi
 */

#ifndef __EBI_WINDOW_H
#define __EBI_WINDOW_H

#include "ebi_config.h"

__EBI_BEGIN_NAMESPACE

class Window
{
 public:
  Window ();
  virtual ~Window ();

  virtual void onIdle (UW time, PNT pos, H cmd, H wid, UW stat);
  virtual W onMenu (UW time, PNT pos, H cmd, H wid, UW stat);
  virtual void onDisplay (W mode, const RECT* rect);
  virtual void onStatus (W sts);
  virtual W onKey (UW time, PNT pos, H key, H ch, UW stat);
  virtual W onPress (UW time, PNT pos, H cmd, UW stat);
  virtual W onFinish (W mode);
  virtual W onPaste (PNT pos);
  virtual W onResponse (W cmd);
  virtual void onScroll (W type, W diff);
  static void onDevice (const TC* devname);
  virtual void onVobj (W type, W vid);
  static W eventLoop ();
  static Window* getActiveWindow ();

 protected:
  virtual void getWinfo (WINFOREC* winfo) const = 0;

 private:
  typedef std::vector<Window*> Windows;
  static Windows s_windows;
  static WFUNCREC s_wfuncs;
  static WINFOREC* s_winfos;

  static Window* getWindow (W ix);
  static Window* findWindow (W wid);
  static W bgfn ();
  static void idlefn ();
  static W msgfn (MESSAGE* msg);
  static W menufn ();
  static void dspfn (W ix, W mode, RECT* rect);
  static void stsfn (W ix, W sts);
  static W keyfn ();
  static W presfn (W ix);
  static W finfn (W ix, W mode);
  static W pastefn (W ix, PNT pos);
  static W respfn (W ix, W cmd);
  static void scrlfn (W ix, W type, W diff);
  static void devfn (TC * devname);
  static void vobjfn (W ix);
};
  
__EBI_END_NAMESPACE

#endif /* __EBI_WINDOW_H */
